pub struct NewMessage {Show 15 fields
pub as_user: Option<String>,
pub attachments: Option<String>,
pub blocks: Option<String>,
pub channel: String,
pub icon_emoji: Option<String>,
pub icon_url: Option<String>,
pub link_names: Option<bool>,
pub mrkdwn: Option<bool>,
pub parse: Option<String>,
pub reply_broadcast: Option<bool>,
pub text: String,
pub thread_ts: Option<String>,
pub unfurl_links: Option<bool>,
pub unfurl_media: Option<bool>,
pub username: Option<String>,
}Expand description
NewMessage
Fields
as_user: Option<String>Pass true to post the message as the authed user, instead of as a bot. Defaults to false. See authorship below.
attachments: Option<String>A JSON-based array of structured attachments, presented as a URL-encoded string.
blocks: Option<String>A JSON-based array of structured blocks, presented as a URL-encoded string.
channel: StringChannel, private group, or IM channel to send message to. Can be an encoded ID, or a name. See below for more details.
icon_emoji: Option<String>Emoji to use as the icon for this message. Overrides icon_url. Must be used in conjunction with as_user set to false, otherwise ignored. See authorship below.
icon_url: Option<String>URL to an image to use as the icon for this message. Must be used in conjunction with as_user set to false, otherwise ignored. See authorship below.
link_names: Option<bool>Find and link channel names and usernames.
mrkdwn: Option<bool>Disable Slack markup parsing by setting to false. Enabled by default.
parse: Option<String>Change how messages are treated. Defaults to none. See below.
reply_broadcast: Option<bool>Used in conjunction with thread_ts and indicates whether reply should be made visible to everyone in the channel or conversation. Defaults to false.
text: StringHow this field works and whether it is required depends on other fields you use in your API call. See below for more detail.
thread_ts: Option<String>Provide another message’s ts value to make this message a reply. Avoid using a reply’s ts value; use its parent instead.
unfurl_links: Option<bool>Pass true to enable unfurling of primarily text-based content.
unfurl_media: Option<bool>Pass false to disable unfurling of media content.
username: Option<String>Set your bot’s user name. Must be used in conjunction with as_user set to false, otherwise ignored. See authorship below.